Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(945)

Unified Diff: src/builtins.cc

Issue 270133003: Poison .arguments and .caller for generator functions (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/builtins.cc
diff --git a/src/builtins.cc b/src/builtins.cc
index d0c1a446a8beb9e80e5ddce6fab385d74468363c..d03f48228bb457a5818258c1183f516e08764e37 100644
--- a/src/builtins.cc
+++ b/src/builtins.cc
@@ -1068,7 +1068,7 @@ BUILTIN(ArrayConcat) {
// -----------------------------------------------------------------------------
// Strict mode poison pills
BUILTIN(StrictModePoisonPill) {
@@ -1078,6 +1078,13 @@ BUILTIN(StrictModePoisonPill) {
}
+BUILTIN(GeneratorPoisonPill) {
+ HandleScope scope(isolate);
+ return isolate->Throw(*isolate->factory()->NewTypeError(
+ "generator_poison_pill", HandleVector<Object>(NULL, 0)));
+}
+
+
// -----------------------------------------------------------------------------
//
@@ -1068,7 +1068,7 @@ BUILTIN(ArrayConcat) {
// -----------------------------------------------------------------------------
-// Strict mode poison pills
+// Generator and strict mode poison pills
BUILTIN(StrictModePoisonPill) {

Powered by Google App Engine
This is Rietveld 408576698